#!/bin/bash
# psave-N-Xfs.sh # Console script.
# Can also be run by typing its symbolic link, psave-N-Xfs.
# 
# (C) musher0, June 20, 2014. GPL3. Rev.: April 3, June 10 & July 16, 2018.
# Please see "LICENCE / LICENSE" below. 
# 
# Purpose: Create, in a Puppy directory, a pupsave file of any number of
# Mb's, containaing an ext2, ext3 or ext4 file system. 
# For use on Puppies where the pupsave creation script seems to be defective, 
# for whatever reason.
#
# Error routines by Karl_Godt. Thanks, Karl.
#
# Examples, taking xenialPup as basis:
# -- psave-N-Xfs a 300 4 
# Creates a pupsave file of 300 Mb's in ext4 named xenialsave-arf.4fs
# -- psave-N-Xfs w 192 2
# Creates a pupsave file of 192 Mb's in ext2 named xenialsave-woof.4fs
#
# Please see "NOTES" below.

####
[ "$1" = "a" ] && A=arf # Choice of names
[ "$1" = "w" ] && A=woof

B="$2" # size in Mb's # Specified by the user.

C="$3" # extension type: ext2, ext3 or ext4.
# Again, specified by the user.
# Simple limits: 2, 3 or 4.
[ "$C" -lt "2" ] && C=2
[ "$C" -gt "4" ] && C=4

# Name of Pup
NOM="`awk -F'=' '$1 ~ /PREFIX/ { print $2 }' /etc/DISTRO_SPECS | cut -d\"'\" -f2`"
[ $? = 0 ] || { echo "Sorry, unable to find the name of your Puppy. Press Return to exit.";read;return 1; }

if [ ! -f "$NOM"save-"$A"."$C"fs ];then
# Creation
	dd if=/dev/zero of="$PWD"/"$NOM"save-"$A"."$C"fs bs=1M count=$B
	[ $? = 0 ] || { echo "Sorry, unable to create savefile correctly. Press Return to exit";read;return 1; }
# Formating 
	mkfs.ext2 -q -m 0 -F "$PWD"/"$NOM"save-"$A"."$C"fs
	[ $? = 0 ] || { echo "Sorry, unable to create filesystem in savefile. Press Return to exit";read;return 1; }

else
     echo -e "\n\t\e[1;33mYou already have a pupsave by that name.
\t\t\tExiting.\e[0m\n"
     exit
fi

exit
####
NOTES
Once that is done, reboot.
The Puppy will pick up the save file on reboot.

However, once on the desktop, you will see icons with question marks.
You may need to update your gtk/gdk cache with the following line:
# gdk-pixbuf-query-loaders --update-cache # (Uncomment to use.)
to regain the normal (original) appearance of the icons.
Source: 
http://www.murga-linux.com/puppy/viewtopic.php?p=722565&sort=lastpost#722565
####
LICENCE / LICENSE
EN -- Q.v. https://opensource.org/licenses/GPL-3.0
# ~~~~
FR -- Ce programme est libre : vous pouvez le redistribuer ou modifier
selon les termes de la Licence Publique Générale GNU publiée par la
Free Software Foundation (v. 3  ou ultérieure, à votre choix).
      Ce programme est distribué dans l'espoir qu'il sera utile, mais SANS
AUCUNE GARANTIE, ni explicite ni implicite, y inclus de commercialisation
ou d'adaptation à un but spécifique. Pour plus de détails, s.v.p. vous
reporter au texte officiel de cette licence à l'adresse Internet ci-dessus
(traduction à http://linux-france.org/article/these/gpl.html), et à
l'explication qui en est donnée à
https://fr.wikipedia.org/wiki/Licence_publique_générale_GNU.
